@@ -37,6 +37,11 @@ ssize_t muroard_cf_au_read(int id, struct muroard_stream * stream, void * buf, s
 ssize_t muroard_cf_riff_wave_read(int id, struct muroard_stream * stream, void * buf, size_t len);
 #endif
 
+#ifdef MUROARD_FEATURE_CODECFILTER_OGG_VORBIS
+ssize_t muroard_cf_ogg_vorbis_read (int id, struct muroard_stream * stream, void * buf, size_t len);
+int     muroard_cf_ogg_vorbis_close(int id, struct muroard_stream * stream);
+#endif
+
 #endif
 
 #endif
