@@ -32,12 +32,12 @@
 #define _FILTER_ANY 0
 
 int muroard_client_init(void) {
- memset(muroard_g_client, 0, sizeof(muroard_g_client)); // state unused = 0!
+ memset(muroard_state_member(client), 0, sizeof(muroard_state_member(client))); // state unused = 0!
 
 #ifdef MUROARD_FEATURE_INTERNAL_CLIENT
- muroard_g_client[0].state  = CLIENT_STATE_INTERNAL;
- muroard_g_client[0].sock   = MUROARD_HANDLE_INVALID;
- muroard_g_client[0].stream = -1;
+ muroard_state_member(client)[0].state  = CLIENT_STATE_INTERNAL;
+ muroard_state_member(client)[0].sock   = MUROARD_HANDLE_INVALID;
+ muroard_state_member(client)[0].stream = -1;
 #endif
 
  return 0;
@@ -48,7 +48,7 @@ int muroard_client_free(void) {
  int ret = 0;
 
  for (i = 0; i < MUROARD_MAX_CLIENTS; i++) {
-  if ( muroard_g_client[i].state != CLIENT_STATE_UNUSED ) {
+  if ( muroard_state_member(client)[i].state != CLIENT_STATE_UNUSED ) {
    if ( muroard_client_delete(i) == -1 )
     ret = -1;
   }
@@ -60,14 +60,14 @@ int muroard_client_free(void) {
 int muroard_client_new(muroard_handle_t sock) {
  int i;
 
- if ( muroard_network_nonblock(sock) == -1 )
+ if ( muroard_network_nonblock(sock, 0) == -1 )
   return -1;
 
  for (i = 0; i < MUROARD_MAX_CLIENTS; i++) {
-  if ( muroard_g_client[i].state == CLIENT_STATE_UNUSED ) {
-   muroard_g_client[i].state  = CLIENT_STATE_NEW;
-   muroard_g_client[i].sock   = sock;
-   muroard_g_client[i].stream = -1;
+  if ( muroard_state_member(client)[i].state == CLIENT_STATE_UNUSED ) {
+   muroard_state_member(client)[i].state  = CLIENT_STATE_NEW;
+   muroard_state_member(client)[i].sock   = sock;
+   muroard_state_member(client)[i].stream = -1;
    return i;
   }
  }
@@ -82,42 +82,42 @@ int muroard_client_delete(int id) {
   return -1;
 
 #ifdef MUROARD_FEATURE_INTERNAL_CLIENT
- if ( muroard_g_client[id].state == CLIENT_STATE_INTERNAL  )
+ if ( muroard_state_member(client)[id].state == CLIENT_STATE_INTERNAL  )
   return 0;
 #endif
 
- if ( muroard_g_client[id].state == CLIENT_STATE_UNUSED   ||
-      muroard_g_client[id].state == CLIENT_STATE_CLOSING   )
+ if ( muroard_state_member(client)[id].state == CLIENT_STATE_UNUSED   ||
+      muroard_state_member(client)[id].state == CLIENT_STATE_CLOSING   )
   return 0;
 
- muroard_g_client[id].state = CLIENT_STATE_CLOSING;
+ muroard_state_member(client)[id].state = CLIENT_STATE_CLOSING;
 
- if ( muroard_g_client[id].stream != -1 ) {
-  if ( muroard_stream_delete(muroard_g_client[id].stream) == -1 )
+ if ( muroard_state_member(client)[id].stream != -1 ) {
+  if ( muroard_stream_delete(muroard_state_member(client)[id].stream) == -1 )
    ret = -1;
  }
 
- if ( muroard_g_client[id].sock != MUROARD_HANDLE_INVALID ) {
-  muroard_network_close(muroard_g_client[id].sock);
+ if ( muroard_state_member(client)[id].sock != MUROARD_HANDLE_INVALID ) {
+  muroard_network_close(muroard_state_member(client)[id].sock);
  }
 
- muroard_g_client[id].state = CLIENT_STATE_UNUSED;
+ muroard_state_member(client)[id].state = CLIENT_STATE_UNUSED;
 
  return ret;
 }
 
 muroard_handle_t muroard_client_exec(int id) {
- muroard_handle_t sock = muroard_g_client[id].sock;
+ muroard_handle_t sock = muroard_state_member(client)[id].sock;
 
- muroard_g_client[id].sock  = MUROARD_HANDLE_INVALID;
- muroard_g_client[id].state = CLIENT_STATE_EXECED;
+ muroard_state_member(client)[id].sock  = MUROARD_HANDLE_INVALID;
+ muroard_state_member(client)[id].state = CLIENT_STATE_EXECED;
 
  return sock;
 }
 
 int muroard_client_handle(int id) {
  struct muroard_message m;
- muroard_handle_t sock = muroard_g_client[id].sock;
+ muroard_handle_t sock = muroard_state_member(client)[id].sock;
  int ret  = 0;
 #ifdef MUROARD_FEATURE_VOLUME_CONTROL
  uint16_t volume;
@@ -163,7 +163,7 @@ int muroard_client_handle(int id) {
    break;
   case MUROAR_CMD_EXEC_STREAM:
     m.datalen =  0;
-    if ( m.stream != (uint16_t)-1 && m.stream == muroard_g_client[id].stream ) {
+    if ( m.stream != (uint16_t)-1 && m.stream == muroard_state_member(client)[id].stream ) {
      if ( muroard_stream_exec(m.stream) == -1 )
       ret = -1;
     } else {
@@ -178,11 +178,11 @@ int muroard_client_handle(int id) {
 #endif
 #ifdef MUROARD_FEATURE_CMD_EXIT
   case MUROAR_CMD_EXIT:
-    // we simply set muroard_g_alive to zero so we will die with the next cycle.
+    // we simply set muroard_state_member(alive) to zero so we will die with the next cycle.
     if ( m.datalen == 0 ) { // default: exit
-     muroard_g_alive  = 0;
+     muroard_state_member(alive)  = 0;
     } else if ( m.datalen == 1 && m.data[0] == 0 ) { // explicit: exit
-     muroard_g_alive  = 0;
+     muroard_state_member(alive)  = 0;
 #ifndef MUROARD_FEATURE_TERMINATE
     } else if ( m.datalen == 1 && m.data[0] == 1 ) { // explicit: terminate
      ret = muroard_network_prefree();
@@ -296,7 +296,7 @@ int muroard_client_handle(int id) {
      tmp    = ntohs(((uint16_t*)m.data)[1]);
      volume = (float)volume*65535.f/(float)tmp;
 //     printf("tmp=%u, volume=%u\n", (unsigned)tmp, (unsigned)volume);
-     muroard_g_stream[m.stream].volume = volume;
+     muroard_state_member(stream)[m.stream].volume = volume;
     }
    break;
 #endif
@@ -396,7 +396,7 @@ int muroard_client_handle(int id) {
 }
 
 int muroard_client_handle_new_stream(int id, struct muroard_message * mes) {
- struct muroar_audio_info info;
+ struct muroard_audio_info info;
  uint32_t * data = (uint32_t*)mes->data;
  int ret;
  int i;
@@ -413,7 +413,7 @@ int muroard_client_handle_new_stream(int id, struct muroard_message * mes) {
  if ( data[1] != (uint32_t)-1 )
   return -1;
 
- if ( data[2] != (uint32_t)muroard_g_sa_rate )
+ if ( data[2] != (uint32_t)muroard_state_member(sa_rate) )
   return -1;
 
  info.bits     = data[3];
@@ -457,23 +457,23 @@ int muroard_client_handle_attach(int id, struct muroard_message * mes) {
  if ( (client + 1) > MUROARD_MAX_CLIENTS )
   return -1;
 
- if ( muroard_g_client[client].state != CLIENT_STATE_NEW      &&
+ if ( muroard_state_member(client)[client].state != CLIENT_STATE_NEW      &&
 #ifdef MUROARD_FEATURE_INTERNAL_CLIENT
-      muroard_g_client[client].state != CLIENT_STATE_INTERNAL &&
+      muroard_state_member(client)[client].state != CLIENT_STATE_INTERNAL &&
 #endif
-      muroard_g_client[client].state != CLIENT_STATE_OLD       )
+      muroard_state_member(client)[client].state != CLIENT_STATE_OLD       )
   return -1;
 
- if ( muroard_g_client[client].stream != -1 )
+ if ( muroard_state_member(client)[client].stream != -1 )
   return -1;
 
  if ( muroard_stream_move_client(mes->stream, client) == -1 )
   return -1;
 
 #ifdef MUROARD_FEATURE_INTERNAL_CLIENT
- if ( muroard_g_client[client].state != CLIENT_STATE_INTERNAL )
+ if ( muroard_state_member(client)[client].state != CLIENT_STATE_INTERNAL )
 #endif
-  muroard_g_client[client].stream = mes->stream;
+  muroard_state_member(client)[client].stream = mes->stream;
 
  mes->datalen = 0;
 
@@ -486,7 +486,7 @@ int muroard_client_handle_server_oinfo(int id, struct muroard_message * mes) {
  uint32_t * data = (uint32_t*) mes->data;
  int        i;
 
- (void)id; // we do not need tis parameter
+ (void)id; // we do not need this parameter
 
  if ( mes->datalen != 0 )
   return -1;
@@ -497,9 +497,9 @@ int muroard_client_handle_server_oinfo(int id, struct muroard_message * mes) {
 
  data[0] =  6; // TODO: do not use magic number. this is ROAR_DIR_MIXING
  data[1] = -1;
- data[2] = muroard_g_sa_rate;
+ data[2] = muroard_state_member(sa_rate);
  data[3] = 16;
- data[4] = muroard_g_sa_channels;
+ data[4] = muroard_state_member(sa_channels);
  data[5] = MUROAR_CODEC_PCM;
 
  for (i = 0; i < 6; i++) {
@@ -516,12 +516,12 @@ int muroard_client_handle_passfh(int id, struct muroard_message * mes) {
 
  mes->datalen = 0;
 
- fh = muroard_network_recvfh(muroard_g_client[id].sock);
+ fh = muroard_network_recvfh(muroard_state_member(client)[id].sock);
 
  if ( fh == MUROARD_HANDLE_INVALID )
   return -1;
 
- if ( muroard_network_nonblock(fh) == -1 ) {
+ if ( muroard_network_nonblock(fh, 0) == -1 ) {
   muroard_network_close(fh);
   return -1;
  }
@@ -562,7 +562,7 @@ int muroard_client_handle_list_clients(int id, struct muroard_message * mes) {
   return -1;
 
  for (i = 0; i < MUROARD_MAX_CLIENTS; i++) {
-  if ( muroard_g_client[i].state != CLIENT_STATE_UNUSED ) {
+  if ( muroard_state_member(client)[i].state != CLIENT_STATE_UNUSED ) {
    mes->data[len++] = i;
   }
  }
@@ -589,7 +589,7 @@ int muroard_client_handle_list_streams(int id, struct muroard_message * mes) {
   return -1;
 
  for (i = 0; i < MUROARD_MAX_STREAMS; i++) {
-  if ( muroard_g_stream[i].state != STREAM_STATE_UNUSED ) {
+  if ( muroard_state_member(stream)[i].state != STREAM_STATE_UNUSED ) {
    mes->data[len++] = i;
   }
  }
@@ -616,7 +616,7 @@ int muroard_client_handle_get_client(int id, struct muroard_message * mes) {
  if ( client >= MUROARD_MAX_CLIENTS )
   return -1;
 
- if ( (c = &(muroard_g_client[client]))->state == CLIENT_STATE_UNUSED )
+ if ( (c = &(muroard_state_member(client)[client]))->state == CLIENT_STATE_UNUSED )
   return -1;
 
  mes->data[len++] = 0; // version
@@ -624,7 +624,7 @@ int muroard_client_handle_get_client(int id, struct muroard_message * mes) {
  if ( c->stream == -1 ) {
   mes->data[len++] = -1; // not execed because we do not have a stream
  } else {
-  if ( muroard_g_stream[c->stream].state == STREAM_STATE_EXECED ) {
+  if ( muroard_state_member(stream)[c->stream].state == STREAM_STATE_EXECED ) {
    mes->data[len++] = c->stream;
   } else {
    mes->data[len++] = -1; // not execed
@@ -638,8 +638,12 @@ int muroard_client_handle_get_client(int id, struct muroard_message * mes) {
   mes->data[len++] = c->stream;
  }
 
- // TODO: support some dummy like "Client %i" or something
  mes->data[len++] = 1; // name has size of one byte
+#ifdef MUROARD_FEATURE_GET_CLIENT_DUMMYNAME
+ snprintf(&(mes->data[len]), sizeof(mes->data) - len, "Client %i", client);
+ mes->data[len - 1] = strlen(&(mes->data[len])) + 1;
+ len += mes->data[len - 1] - 1;
+#endif
  mes->data[len++] = 0; // \0
 
  memset(&(mes->data[len]), 0xFF, 3*4); // PID, UID, GID
@@ -674,7 +678,7 @@ int muroard_client_handle_get_stream(int id, struct muroard_message * mes) {
   return -1;
  }
 
- s = &(muroard_g_stream[mes->stream]);
+ s = &(muroard_state_member(stream)[mes->stream]);
 
  //fprintf(stderr, "%s:%i: dir=%i\n", __FILE__, __LINE__, s->dir);
 
@@ -687,7 +691,7 @@ int muroard_client_handle_get_stream(int id, struct muroard_message * mes) {
 
  data[0] = s->dir;
  data[1] = -1;
- data[2] = muroard_g_sa_rate;
+ data[2] = muroard_state_member(sa_rate);
  data[3] = s->info.bits;
  data[4] = s->info.channels;
  data[5] = s->info.codec;
@@ -745,7 +749,7 @@ int muroard_client_handle_caps(int id, struct muroard_message * mes) {
  if ( mes->data[0] != 0 )
   return -1;
 
- // ceck if type is supported.
+ // check if type is supported.
  if ( mes->data[1] != MUROAR_CT_STANDARDS )
   return -1;
 
