@@ -27,6 +27,14 @@
 #ifndef _MUROARD_DEPS_H_
 #define _MUROARD_DEPS_H_
 
+#if defined(MUROARD_FEATURE_SOCKET_DECNET) && !defined(HAVE_LIB_DNET_DAEMON)
+#undef MUROARD_FEATURE_SOCKET_DECNET
+#endif
+
+#if defined(MUROARD_FEATURE_CODECFILTER_OGG_VORBIS) && !defined(HAVE_LIB_VORBISFILE)
+#undef MUROARD_FEATURE_CODECFILTER_OGG_VORBIS
+#endif
+
 /*** define things we disabple below if not supported ***/
 #ifndef TARGET_MICROCONTROLLER
 #define MUROARD_HAVE_FORK
@@ -39,6 +47,9 @@
 #ifdef MUROARD_FEATURE_HELP_TEXT
 #undef MUROARD_FEATURE_HELP_TEXT
 #endif
+#ifdef MUROARD_FEATURE_VERSION_TEXT
+#undef MUROARD_FEATURE_VERSION_TEXT
+#endif
 #ifdef MUROARD_FEATURE_SOCKET_UNIX
 #undef MUROARD_FEATURE_SOCKET_UNIX
 #endif
@@ -53,6 +64,9 @@
 #ifdef MUROARD_FEATURE_HELP_TEXT
 #undef MUROARD_FEATURE_HELP_TEXT
 #endif
+#ifdef MUROARD_FEATURE_VERSION_TEXT
+#undef MUROARD_FEATURE_VERSION_TEXT
+#endif
 #endif
 
 
@@ -69,6 +83,11 @@
 #ifdef MUROARD_FEATURE_SOCKET_UNIX
 #undef MUROARD_FEATURE_SOCKET_UNIX
 #endif
+
+// DECnet sockets:
+#ifdef MUROARD_FEATURE_SOCKET_DECNET
+#undef MUROARD_FEATURE_SOCKET_DECNET
+#endif
 #endif
 
 // disable things Win32 does not support:
@@ -152,6 +171,8 @@
 #define MUROARD_DEFAULT_LISTEN_TYPE        MUROARD_NETWORK_TYPE_UNIX
 #elif defined(MUROARD_FEATURE_SOCKET_INET)
 #define MUROARD_DEFAULT_LISTEN_TYPE        MUROARD_NETWORK_TYPE_INET
+#elif defined(MUROARD_FEATURE_SOCKET_DECNET)
+#define MUROARD_DEFAULT_LISTEN_TYPE        MUROARD_NETWORK_TYPE_DECNET
 #else
 #undef MUROARD_FEATURE_SOCKET_LISTEN
 #endif
@@ -166,6 +187,14 @@
 #endif
 #endif
 
+#if defined(MUROARD_FEATURE_SOCKET_DECNET) && !defined(MUROARD_FEATURE_SOCKET_LISTEN_SOCKTYPE)
+#define MUROARD_FEATURE_SOCKET_LISTEN_SOCKTYPE
+#endif
+
+#if defined(MUROARD_FEATURE_REREADWRITE) && defined(__WIN32)
+#undef MUROARD_FEATURE_REREADWRITE
+#endif
+
 #endif
 
 //ll
