@@ -58,40 +58,55 @@ int muroard_driver_init(const char * dev) {
 #ifndef DRIVER_HAVE_FREE
 int muroard_driver_free(void) {
 #ifdef DRIVER_USE_SYSIO
- if ( DRIVER_SYSIO_FH != -1 )
-  return close(DRIVER_SYSIO_FH);
+ if ( muroard_state_member(driver_fh) != -1 )
+  return close(muroard_state_member(driver_fh));
 #endif
  return 0;
 }
 #endif
 
 #ifndef DRIVER_HAVE_WRITE
-int muroard_driver_write(int16_t * data) {
+ssize_t muroard_driver_write(int16_t * data, size_t len, enum muroard_blocking blocking) {
 #ifdef DRIVER_USE_SYSIO
  ssize_t ret;
- size_t need = muroard_g_abuffer_size;
+ size_t done = 0;
 
- while (need) {
-  ret = write(DRIVER_SYSIO_FH, data, need);
+ if ( blocking != muroard_state_member(driver_old_blocking) ) {
+  muroard_network_nonblock(muroard_state_member(driver_fh), blocking != MUROARD_BLOCKING_NONE);
+  muroard_state_member(driver_old_blocking) = blocking;
+ }
+
+ while (len) {
+  ret = write(muroard_state_member(driver_fh), data, len);
+
+#ifndef __WIN32
+  if ( blocking == MUROARD_BLOCKING_NONE && ret == -1 && errno == EAGAIN )
+   ret = 0;
+#endif
 
   if ( ret > 0 ) {
-   need -= ret;
+   done += ret;
+   len  -= ret;
    data += ret;
   } if ( ret < 0 ) {
    return -1;
   } else { // ret == 0
-   return 0;
+   return done;
   }
  }
+ return done;
+
 #else
  (void)data;
+ if ( blocking == MUROARD_BLOCKING_NONE )
+  return len;
 #ifndef __WIN32
  usleep(muroard_g_abuffer_size*1000000LLU/(long long unsigned)(muroard_g_sa_rate*muroard_g_sa_channels*2));
 #else
  Sleep(muroard_g_abuffer_size*1000LLU/(long long unsigned)(muroard_g_sa_rate*muroard_g_sa_channels*2));
 #endif
+ return len;
 #endif
- return 0;
 }
 #endif
 
