@@ -37,7 +37,7 @@
 
 int muroard_driver_init(const char * dev);
 int muroard_driver_free(void);
-int muroard_driver_write(int16_t * data);
+ssize_t muroard_driver_write(int16_t * data, size_t len, enum muroard_blocking blocking);
 
 #endif
 
