@@ -29,17 +29,18 @@
 #define DRIVER_HAVE_INIT
 #define DRIVER_USE_SYSIO
 
-static int muroard_driver_muroar_fh = -1;
-
-#define DRIVER_SYSIO_FH muroard_driver_muroar_fh
-
 int muroard_driver_init(const char * dev) {
 
- if ( (muroard_driver_muroar_fh = muroar_connect(dev, MUROARD_DEFAULT_DRIVER_CLIENT_NAME)) == -1 )
+ if ( (muroard_state_member(driver_fh) = muroar_connect(dev, MUROARD_DEFAULT_DRIVER_CLIENT_NAME)) == -1 )
   return -1;
 
- if ( (muroard_driver_muroar_fh = muroar_stream(muroard_driver_muroar_fh, MUROAR_PLAY_WAVE,
-                                         NULL, MUROAR_CODEC_PCM, muroard_g_sa_rate, muroard_g_sa_channels, 16)) == -1 )
+ if ( (muroard_state_member(driver_fh) = muroar_stream(muroard_state_member(driver_fh),
+                                                       MUROAR_PLAY_WAVE,
+                                                       NULL,
+                                                       MUROAR_CODEC_PCM,
+                                                       muroard_state_member(sa_rate),
+                                                       muroard_state_member(sa_channels),
+                                                       16)) == -1 )
   return -1;
  
  return 0;
