@@ -37,7 +37,7 @@
 #define DRIVER_HAVE_FREE
 #define DRIVER_HAVE_WRITE
 
-static struct driver_wmm {
+struct driver_wmm {
   UINT  id;             /* device id                       */
   HWAVEOUT hwo;         /* waveout handler                 */
   WAVEOUTCAPS caps;     /* device caps                     */
@@ -64,7 +64,7 @@ static struct driver_wmm {
   int full_blocks;      /* Number of waveheader full (ready to send).  */
   int widx;             /* Index to the block being currently filled.  */
   int ridx;             /* Index to the block being sent.              */
-} _self;
+};
 
 
 
@@ -223,20 +223,22 @@ static int _send_block(struct driver_wmm * self, const int idx) {
 
 
 int muroard_driver_init(const char * dev) {
- struct driver_wmm * self = &_self;
+ struct driver_wmm * self = muroard_malloc(sizeof(struct driver_wmm));
  MMRESULT mmres;
 
+ muroard_state_member(driver_vp) = self;
+
  dbg printf("muroard_driver_init(dev='%s') = ?\n", dev);
  dbg printf("muroard_driver_init(dev='%s'): rate=%i, channels=%i, bits=16\n",
-                 dev, muroard_g_sa_rate, muroard_g_sa_channels);
+                 dev, muroard_state_member(sa_rate), muroard_state_member(sa_channels));
 
- muroard_memzero(&_self, sizeof(_self));
+ muroard_memzero(self, sizeof(*self));
 
  // WMM Setup:
  self->wavefmt.wFormatTag      = WAVE_FORMAT_PCM;
- self->wavefmt.nChannels       = muroard_g_sa_channels;
+ self->wavefmt.nChannels       = muroard_state_member(sa_channels);
  self->wavefmt.wBitsPerSample  = 16;
- self->wavefmt.nSamplesPerSec  = muroard_g_sa_rate;
+ self->wavefmt.nSamplesPerSec  = muroard_state_member(sa_rate);
  self->wavefmt.nBlockAlign     = (self->wavefmt.wBitsPerSample>>3)*self->wavefmt.nChannels;
  self->wavefmt.nAvgBytesPerSec = self->wavefmt.nSamplesPerSec*self->wavefmt.nBlockAlign;
  self->wavefmt.cbSize          = 0;
@@ -251,7 +253,7 @@ int muroard_driver_init(const char * dev) {
   self->splPerBlock = MUROARD_DEFAULT_FRAMES_PER_CYCLE;
 #endif
   self->msPerBlock  =
-    (self->splPerBlock * 1000 + muroard_g_sa_rate - 1) / muroard_g_sa_rate;
+    (self->splPerBlock * 1000 + muroard_state_member(sa_rate) - 1) / muroard_state_member(sa_rate);
 
   mmres =
     waveOutOpen(&(self->hwo),
@@ -278,81 +280,87 @@ int muroard_driver_init(const char * dev) {
 }
 
 int muroard_driver_free(void) {
+ struct driver_wmm * self = muroard_state_member(driver_vp);
+
  dbg printf("muroard_driver_free(void) = ?\n");
 
- if ( _self.opened ) {
-  _wait_wave_headers(&_self, 1);
-  _free_wave_headers(&_self);
-  waveOutClose(_self.hwo);
+ if ( self->opened ) {
+  _wait_wave_headers(self, 1);
+  _free_wave_headers(self);
+  waveOutClose(self->hwo);
  }
 
+ muroard_free(self);
  dbg printf("muroard_driver_free(void) = 0\n");
  return 0;
 }
 
-int muroard_driver_write(int16_t * data) {
- size_t  count  = muroard_g_abuffer_size;
- ssize_t ret_ok = count;
+ssize_t muroard_driver_write(int16_t * data, size_t len, enum muroard_blocking blocking) {
+ struct driver_wmm * self = muroard_state_member(driver_vp);
+ ssize_t ret_ok = len;
  int ret = 1;
 
+ if ( blocking == MUROARD_BLOCKING_NONE )
+  return -1;
+
  dbg printf("muroard_driver_write(data=%p) = ?\n", data);
 
- if ( ! _self.opened )
+ if ( ! self->opened )
   return -1;
 
  dbg printf("muroard_driver_write(data=%p) = ?\n", data);
 
   dbg printf("-----------------\n");
 
-  while(ret && count > 0) {
+  while(ret && len > 0) {
     int n;
-    const int idx = _get_free_block(&_self);
+    const int idx = _get_free_block(self);
 
     dbg printf("muroard_driver_write(data=%p): XXX\n", data);
 
     if (idx == -1) {
-      dbg printf("sleep of %ims\n", _self.msPerBlock);
-      Sleep(_self.msPerBlock);
+      dbg printf("sleep of %ims\n", self->msPerBlock);
+      Sleep(self->msPerBlock);
       continue;
     } else {
       dbg printf("continue...\n");
     }
 
     /* Get free bytes in the block */
-    n = _self.wh[idx].wh.dwBufferLength
-      - _self.wh[idx].count;
+    n = self->wh[idx].wh.dwBufferLength
+      - self->wh[idx].count;
 
     /*     debug("free in block %d : %d/%d\n", */
     /*    idx,n,internal->wh[idx].dwBufferLength); */
 
     /* Get amount to copy */
-    if (n > (int)count) {
-      n = count;
+    if (n > (int)len) {
+      n = len;
     }
     /*     debug("copy = %d\n",n); */
 
 
 
     /* Do copy */
-    CopyMemory((char*)_self.wh[idx].wh.lpData
-               + _self.wh[idx].count,
+    CopyMemory((char*)self->wh[idx].wh.lpData
+               + self->wh[idx].count,
                data, n);
 
     /* Updates pointers and counters */
     data += n;
-    count -= n;
+    len -= n;
     /*     debug("rem = %d\n",num_bytes); */
-    _self.wh[idx].count += n;
+    self->wh[idx].count += n;
 
     /* Is this block full ? */
-    if (_self.wh[idx].count
-        == _self.wh[idx].wh.dwBufferLength) {
-      ++_self.full_blocks;
+    if (self->wh[idx].count
+        == self->wh[idx].wh.dwBufferLength) {
+      ++self->full_blocks;
       /*       debug("blocks %d full, total:%d\n",internal->widx,internal->full_blocks); */
-      if (++_self.widx == _self.blocks) {
-        _self.widx = 0;
+      if (++self->widx == self->blocks) {
+        self->widx = 0;
       }
-      ret = _send_block(&_self, idx);
+      ret = _send_block(self, idx);
     }
   }
 
