@@ -27,6 +27,10 @@
 #include "muroard.h"
 
 int main (int argc, char * argv[]) {
+ struct muroard_state state;
+
+ muroard_g_state = &state;
+
  return muroard_main(argc, argv);
 }
 
