@@ -37,6 +37,10 @@ void   muroard_free(void * ptr);
 #define muroard_free(ptr)           free((ptr))
 #endif
 
+#ifndef muroard_memzero
+#define muroard_memzero(ptr,size)  memset((ptr), 0, (size))
+#endif
+
 #ifdef MUROARD_MEMMGR_LOCK_ALL
 int    muroard_memmgr_lock_all(void);
 #endif
