@@ -35,8 +35,8 @@ struct muroard_message {
  char data[MUROARD_MAX_MSGSIZE];
 };
 
-int muroard_proto_recv(int sock, struct muroard_message * mes);
-int muroard_proto_send(int sock, struct muroard_message * mes);
+int muroard_proto_recv(muroard_handle_t sock, struct muroard_message * mes);
+int muroard_proto_send(muroard_handle_t sock, struct muroard_message * mes);
 
 
 #endif
