@@ -29,7 +29,7 @@
 
 int muroard_waveform_init(void);
 int muroard_waveform_free(void);
-int muroard_waveform_update(void);
+int muroard_waveform_update(enum muroard_blocking blocking);
 
 #ifdef MUROARD_FEATURE_STANDBY
 int muroard_waveform_standby(int manual_mode, int auto_mode);
